==> HinemosWebClient_src-2.0.0.tar.gz: HinemosWebClient_src-2.0.0/js/repository/scope.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

/*******************************************************************************
 * Create repository scope
 */
var fn = function() {
	var __ = cm;

	var view = $.extend({}, __._fnview_tree_grid, {
		load_flg    : false
		,facility_id: ""
		,/*
		 * Set caption of grid
		 */
		setCaption : function(path) {
			this.grid.setCaption([ __.getLang("scope"), ": ", path ].join(""));
		}

		,/*
		 * On click a node of tree
		 */
		onclickTree : function(node_data) {
			var _ = this;
			
			_.facility_id = node_data.facilityId;
			_.setCaption(node_data.path);
			
			if (!(_.load_flg)) {
				_.load_flg = true;
				_.reloadGrid();
				
			}
		}
		
		,reloadGrid: function(){
			var _ = this;
			
			_.grid.refreshData({
				facilityId: _.facility_id
			});
		}
		
		,/*
		 * Get scope list
		 */
		createGrid : function() {
			var _ = this;

			$.ajax({
				url : "get_repository_scope_list_table_define",
				cache   : false,
				dataType : "json",
				type : "get",
				success : function(data_respond) {
					// Cache local variants
					var grid = _.grid, pager = grid.$pgr;

					// Check validation of data_respond
					if (__.checkJsonError(data_respond) !== true) {
						return;
					}

					// Set some options for grid
					$.extend(data_respond, {
						url : "get_repository_scope_list",
						pager : pager,
						caption : "&nbsp;",
						viewrecords : true,
						loadComplete: function(){
							var post_Data = grid.getGridParam("postData")
							,facility_id
							;
							
							if((facility_id = post_Data.facilityId) === undefined){
								facility_id = "";
							}
							
							if(facility_id === _.facility_id){
								_.load_flg = false;
							}else{
								setTimeout(function(){
									_.reloadGrid();
								}, 1);
							}
						}
					});

					grid.processData(data_respond, ["facilityId"]);
					grid.controlSize();
					_.setCaption("");
					if(pager){
						pager.find('tbody').find('#grid_pager_repository_scope_center').width(10);
					}
				},
				error : __.loadDataError
			});
		}

		,/*
		 * Get facility tree
		 */
		getTree : function() {
			return __.fclt_tree.get();
		}

		,/*
		 * Reset data of panes of views
		 */
		resetView : function() {
			var _ = this;
			__.repository.scope.content.tree.append($("<div class='tree-loading'></div>"));

			__.fclt_tree.getData();
			_.facility_id = "";
			_.grid.refreshData({
				facilityId : ""
			}, true);

			_.setCaption("");
		}

		,/*
		 * Bind some action
		 */
		bindAction : function() {
			var _ = this;
			var _btns = _.$btns;

			// Bind actions for button in left of pane
			// Bind update grid data
			_btns.children("#update").click(function() {
				_.resetView();
			});

			// Bind toggle left pane
			_btns.children("#toggle_view").click(function() {
				_.togglePane("west", this);
			});
		}
	});

	return view;
};

==> HinemosWebClient_src-2.0.2.tar.gz: HinemosWebClient_src-2.0.2/js/repository/scope.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

/*******************************************************************************
 * Create repository scope
 */
var fn = function() {
	var __ = cm
	,load_tree = false
	, _pers     = this;

	var view = $.extend({}, __._fnview_tree_grid, {
		load_flg    : false
		,facility_id: ""
		,manager_ip: ""
		,/*
		 * Set caption of grid
		 */
		setCaption : function(path, managerIp) {
			if (managerIp == null || managerIp == "") {
				this.grid.setCaption([__.getLang("scope"), ": " , path].join(""));
			} else {
				this.grid.setCaption([__.getLang("scope"), "(", managerIp, "): " , path].join(""));
			}
		}

		,/*
		 * On click a node of tree
		 */
		onclickTree : function(node_data) {
			var _ = this;
			
			_.facility_id = node_data.facilityId;
			_.manager_ip = node_data.managerIp;
			_.setCaption(node_data.path, _.manager_ip);
			
			if (!(_.load_flg)) {
				_.load_flg = true;
				_.reloadGrid();
				
			}
		}
		
		,reloadGrid: function(){
			var _ = this;
			
			_.grid.refreshData({
				facilityId: _.facility_id,
				managerIpForSearch: _.manager_ip
			});
		}
		
		,/*
		 * Get scope list
		 */
		createGrid : function() {
			var _ = this;

			$.ajax({
				url : "get_repository_scope_list_table_define",
				cache   : false,
				dataType : "json",
				type : "get",
				success : function(data_respond) {
					// Cache local variants
					var grid = _.grid, pager = grid.$pgr;

					// Check validation of data_respond
					if (__.checkJsonError(data_respond) !== true) {
						return;
					}

					// Set some options for grid
					$.extend(data_respond, {
						url : "get_repository_scope_list",
						pager : pager,
						caption : "&nbsp;",
						viewrecords : true,
						loadComplete: function(){
							var post_Data = grid.getGridParam("postData")
							,facility_id
							;
							
							if((facility_id = post_Data.facilityId) === undefined){
								facility_id = "";
							}
							
							if(facility_id === _.facility_id){
								_.load_flg = false;
							}else{
								setTimeout(function(){
									_.reloadGrid();
								}, 1);
							}
						}
					});

					grid.processData(data_respond, ["facilityId"]);
					grid.controlSize();
					if(pager){
						pager.find('tbody').find('#grid_pager_repository_scope_center').width(10);
					}
				},
				error : __.loadDataError
			});
			if(load_tree == false)
			{
				load_tree = _.resetView();
			}
		}

		,/*
		 * Get facility tree
		 */
		getTree : function() {
//			__.fclt_tree.getData(true);
//			var obj = __.fclt_tree.get();
//			return obj;
//			_pers.repository_tree.getData();
			return _pers.repository_tree.get();
		}

		,/*
		 * Reset data of panes of views
		 */
		resetView : function() {
			var _ = this;
			__.repository.scope.content.tree.append($("<div class='tree-loading'></div>"));

			_pers.repository_tree.getData();
			__.fclt_tree.getData();
			_.facility_id = "";
			_.grid.refreshData({
				facilityId : "",
				managerIpForSearch: _.manager_ip
			}, true);

			return true;
		}

		,/*
		 * Bind some action
		 */
		bindAction : function() {
			var _ = this;
			var _btns = _.$btns;

			// Bind actions for button in left of pane
			// Bind update grid data
			_btns.children("#update").click(function() {
				_.resetView();
			});

			// Bind toggle left pane
			_btns.children("#toggle_view").click(function() {
				_.togglePane("west", this);
			});
		}
	});

	return view;
};
